@@ -308,9 +308,7 @@ class UpdatesAvailable(InternalDialog):
 
         pkg_toggle_renderer = Gtk.CellRendererToggle()
         pkg_toggle_renderer.set_property("ypad", 2)
-        pkg_toggle_renderer.connect(
-            "toggled", self.on_update_toggled, self.treeview_update
-        )
+        pkg_toggle_renderer.connect("toggled", self.on_update_toggled)
         pkg_column.pack_start(pkg_toggle_renderer, False)
         pkg_column.add_attribute(
             pkg_toggle_renderer, "active", LIST_TOGGLE_ACTIVE
@@ -609,13 +607,6 @@ class UpdatesAvailable(InternalDialog):
         model = widget.get_model()
         iter = model.get_iter(path)
 
-        # Screen reader: Speak state of toggle box
-        ac = widget.get_accessible()
-        if model.get_value(iter, LIST_TOGGLE_ACTIVE):
-            ac.emit("notification", _("Selected"), 0)
-        else:
-            ac.emit("notification", _("Unselected"), 0)
-
         # set descr
         data = model.get_value(iter, LIST_UPDATE_DATA)
         item = data.item
@@ -792,6 +783,8 @@ class UpdatesAvailable(InternalDialog):
             )
         else:
             self.window_main.get_window().set_cursor(None)
+        while Gtk.events_pending():
+            Gtk.main_iteration()
 
     def _mark_selected_updates(self):
         def foreach_cb(model, path, iter, data):
@@ -828,7 +821,6 @@ class UpdatesAvailable(InternalDialog):
         self.hbox_restart.set_visible(requires_restart)
 
     def _refresh_updates_count(self):
-        self.button_install.show()
         self.button_install.set_sensitive(
             self.cache.install_count + self.cache.del_count
         )
@@ -864,7 +856,7 @@ class UpdatesAvailable(InternalDialog):
                       and not self.list.ubuntu_pro_groups):
                     download_str = _("You need to enable Ubuntu Pro to install"
                                      " these updates.")
-                    self.button_install.hide()
+                    self.button_install.destroy()
                 else:
                     download_str = _("There are no updates to install.")
                     self.button_install.set_sensitive(False)
@@ -1075,7 +1067,7 @@ class UpdatesAvailable(InternalDialog):
             self.hbox_on_3g.hide()
             self.hbox_roaming.hide()
 
-    def on_update_toggled(self, renderer, path, treeview):
+    def on_update_toggled(self, renderer, path):
         """a toggle button in the listview was toggled"""
         iter = self.store.get_iter(path)
         data = self.store.get_value(iter, LIST_UPDATE_DATA)
@@ -1090,19 +1082,12 @@ class UpdatesAvailable(InternalDialog):
         else:
             self.toggle_from_items([data.item])
 
-        # Screen reader: Speak state of toggle box
-        ac = treeview.get_accessible()
-        if self.store.get_value(iter, LIST_TOGGLE_ACTIVE):
-            ac.emit("notification", _("Selected"), 0)
-        else:
-            ac.emit("notification", _("Unselected"), 0)
-
     def on_treeview_update_row_activated(self, treeview, path, column, *args):
         """
         If an update row was activated (by pressing space), toggle the
         install check box
         """
-        self.on_update_toggled(None, path, treeview)
+        self.on_update_toggled(None, path)
 
     def toggle_from_items(self, items):
         self.setBusy(True)
@@ -1270,5 +1255,7 @@ class UpdatesAvailable(InternalDialog):
         self.update_close_button()
         self.update_count()
         self.setBusy(False)
+        while Gtk.events_pending():
+            Gtk.main_iteration()
         self.updates_changed()
         return False
